ListProjectsResult class

Result structure used for requests to list projects in AWS Mobile Hub.

Constructors

ListProjectsResult({String? nextToken, List<ProjectSummary>? projects})
ListProjectsResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
final
projects → List<ProjectSummary>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited