Resource class

Information about an instance of an AWS resource associated with a project.

Constructors

Resource({String? arn, Map<String, String>? attributes, String? feature, String? name, String? type})
Resource.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
final
attributes → Map<String, String>?
final
feature → String?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited