UpdateProjectResult class

Result structure used for requests to updated project configuration.

Constructors

UpdateProjectResult({ProjectDetails? details})
UpdateProjectResult.fromJson(Map<String, dynamic> json)
factory

Properties

details → ProjectDetails?
Detailed information about the updated AWS Mobile Hub project.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited